Type: Package
Package: ipeaplot
Title: Add Ipea Editorial Standards to 'ggplot2' Graphics
Version: 0.5.2
Authors@R: c(
    person("Pedro", "Ferreira", role=c("aut","cre"), email="pedro.ferreira2@ipea.gov.br"),
    person("Pedro","Jorge", role=c("aut"), email="pedro.alves@ipea.gov.br"),
    person("Daniel","Lima", role="aut", email="daniel.viegas@ipea.gov.br"),
    person("Gustavo","Coelho", role="aut", email="gustavo.coelho@ipea.gov.br"),
    person("Rafael H. M.", "Pereira", role = "aut", email="rafa.pereira.br@gmail.com"),
    person("Lucas","Mation", role="aut", email="lucas.mation@ipea.gov.br"),
    person("Fabio","Vaz", role="ctb", email="fabio.vaz@ipea.gov.br"),
    person("Ipea - Institue for Applied Economic Research", role = c("cph", "fnd")))
Maintainer: Pedro Ferreira <pedro.ferreira2@ipea.gov.br>
Description: Convenient functions to create 'ggplot2' graphics following the 
             editorial guidelines of the  Institute for Applied Economic 
             Research (Ipea).
License: MIT + file LICENSE
URL: https://github.com/ipeadata-lab/ipeaplot
BugReports: https://github.com/ipeadata-lab/ipeaplot/issues
Depends: R (>= 3.3.2)
Imports: checkmate, ggplot2, grDevices, paletteer, scales, rlang,
        ggthemes, svglite, ragg
Suggests: abjData, data.table, dplyr, forcats, geobr, knitr, patchwork,
        purrr, reshape, rmarkdown, sf, sysfonts, testthat, tidyr
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-20 12:45:01 UTC; caval
Author: Pedro Ferreira [aut, cre],
  Pedro Jorge [aut],
  Daniel Lima [aut],
  Gustavo Coelho [aut],
  Rafael H. M. Pereira [aut],
  Lucas Mation [aut],
  Fabio Vaz [ctb],
  Ipea - Institue for Applied Economic Research [cph, fnd]
Repository: CRAN
Date/Publication: 2026-05-20 13:10:02 UTC
Built: R 4.6.0; ; 2026-05-25 03:59:36 UTC; unix
