# Generated by roxygen2: do not edit by hand

S3method(ggplot_add,scale_auto_ipea)
S3method(ggplot_add,scale_ipea_color)
S3method(ggplot_add,scale_ipea_fill)
export(ipea_pal)
export(save_ipeaplot)
export(scale_color_ipea)
export(scale_fill_ipea)
export(theme_ipea)
import(ggplot2)
import(ggthemes)
import(ragg)
import(rlang)
importFrom(grDevices,dev.off)
importFrom(grDevices,postscript)
